<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Præferencer for vindueshåndtering</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="38"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="43"/>
        <source>Appearance</source>
        <translation>Udseende</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="48"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="53"/>
        <location filename="../obconf.ui" line="114"/>
        <source>Windows</source>
        <translation>Vinduer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="58"/>
        <source>Move &amp; Resize</source>
        <translation>Flyt og tilpas størrelse</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="63"/>
        <source>Mouse</source>
        <translation>Mus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="68"/>
        <source>Desktops</source>
        <translation>Skriveborde</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="73"/>
        <source>Margins</source>
        <translation>Marginer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="78"/>
        <source>Dock</source>
        <translation>Dok</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="96"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Installer et nyt tema...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="103"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Opret et tema&amp;arkiv (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="120"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>&amp;Vinduer beholder en ramme når de er udekoreret</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="127"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>&amp;Animer minimer og gendan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="137"/>
        <source>Window Titles</source>
        <translation>Vinduestitler</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="143"/>
        <source>Button order:</source>
        <translation>Rækkefølge på knapper:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="153"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Vinduesikon
L: Vinduestitel
I: Minimer
M: Maksimer
C: Luk
S: Rul op
D: Allestedsnærværende (på alle skriveborde)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="231"/>
        <source>&amp;Active window title: </source>
        <translation>&amp;Aktiv vinduestitel: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="241"/>
        <source>&amp;Inactive window title: </source>
        <translation>&amp;Inaktiv vinduestitel: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="251"/>
        <source>Menu &amp;header: </source>
        <translation>Vinduesov&amp;erskrift: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="261"/>
        <source>&amp;Menu Item: </source>
        <translation>&amp;Menupunkt: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="271"/>
        <source>Active &amp;On-screen display: </source>
        <translation>A&amp;ktiv skærmdisplay: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="281"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Inak&amp;tiv skærmdisplay: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="295"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Fokusér på &amp;nye vinduer når de vises</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="302"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Placér nye vinduer under musemarkøren</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="309"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Centrér nye vinduer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="318"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>Foretræk at placere nye vinduer &amp;på:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="329"/>
        <source>All monitors</source>
        <translation>Alle skærme</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="334"/>
        <source>The active monitor</source>
        <translation>Den aktive skærm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="339"/>
        <source>The monitor with the mouse</source>
        <translation>Skærmen med musen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="344"/>
        <source>Primary monitor</source>
        <translation>Primær skærm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="354"/>
        <source>Primary Monitor</source>
        <translation>Primær skærm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="360"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>Den primære skærm er den hvor Openbox placerer dialoger, såsom den der bruges til at gennemløbe vinduer.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="370"/>
        <source>Primary &amp;monitor:</source>
        <translation>Primær &amp;skærm:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="381"/>
        <source>Fixed Monitor</source>
        <translation>Fast skærm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="386"/>
        <source>Active Monitor</source>
        <translation>Aktiv skærm</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="391"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Skærm med musemarkør</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="399"/>
        <source>&amp;Fixed monitor:</source>
        <translation>&amp;Fast skærm:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="439"/>
        <source>Moving and Resizing Windows</source>
        <translation>Flytning og størrelsesændring af vinduer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="445"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Opdater vinduets indhold under &amp;størrelsesændring</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="452"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>Trække-&amp;tærskel afstand:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="472"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Modstand mod andre &amp;vinduer:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="492"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Modstand mod skærm&amp;kanter:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="512"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>&amp;Forsinkelse inden der skiftes:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="532"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>&amp;Skift skrivebord når et vindue flyttes forbi skærmkanten</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>Information Dialog</source>
        <translation>Informationsdialog</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="549"/>
        <location filename="../obconf.ui" line="578"/>
        <source>Centered</source>
        <translation>Centreret</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="554"/>
        <source>From left edge</source>
        <translation>Fra venstre kant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="559"/>
        <source>From right edge</source>
        <translation>Fra højre kant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="567"/>
        <source>Fixed &amp;y position:</source>
        <translation>Fast &amp;y-placering:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="583"/>
        <source>From top edge</source>
        <translation>Fra øverste kant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="588"/>
        <source>From bottom edge</source>
        <translation>Fra nederste kant</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="596"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>Informationsdialogens &amp;placering:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="606"/>
        <source>Fixed &amp;x position:</source>
        <translation>Fast &amp;x-placering:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="616"/>
        <source>Show &amp;information dialog:</source>
        <translation>Vis &amp;informationsdialog:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="641"/>
        <source>When resizing terminal windows</source>
        <translation>Når størrelsen på terminalvinduer ændres</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="646"/>
        <source>Always</source>
        <translation>Altid</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="651"/>
        <source>Never</source>
        <translation>Aldrig</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="660"/>
        <source>Centered on the window</source>
        <translation>Centreret på vinduet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="665"/>
        <source>Above the window</source>
        <translation>Over vinduet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="670"/>
        <source>Fixed position on screen</source>
        <translation>Fast placering på skærmen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="701"/>
        <source>Focusing Windows</source>
        <translation>Vinduesfokus</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Fokusér vinduer når musemarkøren bevæges over dem</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="722"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>F&amp;orsinkelse inden fokusering og hævning af vinduer:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="742"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Flyt fokus under musemarkøren ved &amp;skift af skrivebord</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="749"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Flyt fokus &amp;under musemarkøren når musen ikke flyttes</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>&amp;Hæv vinduer når musemarkøren flyttes over dem</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="768"/>
        <source>Titlebar</source>
        <translation>Titellinje</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="774"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Dobbeltklik på &amp;titellinjen:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="785"/>
        <source>Maximizes the window</source>
        <translation>Maksimerer vinduet</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="790"/>
        <source>Shades the window</source>
        <translation>Ruller vinduet op</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="798"/>
        <source>Double click ti&amp;me:</source>
        <translation>Dobbeltklikst&amp;id:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="838"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>&amp;Vis en underretning når der skiftes skrivebord</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="845"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>Visningstid for &amp;underretningen:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="868"/>
        <source>&amp;Number of desktops: </source>
        <translation>&amp;Antal skriveborde: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="891"/>
        <source>&amp;Desktop names:</source>
        <translation>&amp;Skrivebordsnavne:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="905"/>
        <source>Desktop Margins</source>
        <translation>Skrivebordsmarginer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="911"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Skrivebordsmarginer er reserverede områder på kanten af skærmen. Nye vinduer vil ikke blive placeret over en margin, og maksimerede vinduer vil ikke dække dem.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="921"/>
        <source>Left:</source>
        <translation>Venstre:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="935"/>
        <location filename="../obconf.ui" line="956"/>
        <location filename="../obconf.ui" line="977"/>
        <location filename="../obconf.ui" line="998"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="942"/>
        <source>Top:</source>
        <translation>Øverst:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="963"/>
        <source>Right:</source>
        <translation>Højre:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="984"/>
        <source>Bottom:</source>
        <translation>Nederst:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1025"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Dokken er en særlig beholder til &quot;dokapps&quot;, eller dokprogrammer. Den er ikke synlige på skærmen før et dokprogram startes. Dokapps kan bruges til at vise ting såsom et ur, eller til at give dig en systembakke.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>Position</source>
        <translation>Placering</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1053"/>
        <source>&amp;Position:</source>
        <translation>&amp;Placering:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1067"/>
        <source>Top Left</source>
        <translation>Øverst til venstre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1072"/>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1077"/>
        <source>Top Right</source>
        <translation>Øverst til højre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1082"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1087"/>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1092"/>
        <source>Bottom Left</source>
        <translation>Nederst til venstre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1097"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1102"/>
        <source>Bottom Right</source>
        <translation>Nederst til højre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1107"/>
        <source>Floating</source>
        <translation>Svævende</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1121"/>
        <source>&amp;Floating position:</source>
        <translation>&amp;Svævende placering:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1146"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1162"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Tillad &amp;vinduer at blive placeret i dokkens område</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1169"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Orientering: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1183"/>
        <source>Vertical</source>
        <translation>Lodret</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1188"/>
        <source>Horizontal</source>
        <translation>Vandret</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1199"/>
        <source>Stacking</source>
        <translation>Stabling</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1205"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Hold dokken over &amp;andre vinduer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1212"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Ti&amp;llad dokken at være både over og under vinduer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1219"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Hold dokken &amp;under andre vinduer</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1229"/>
        <source>Hiding</source>
        <translation>Skjul</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1235"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Forsinkelse inden skjul:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1245"/>
        <source>Delay before &amp;showing:</source>
        <translation>Forsinkelse inden vi&amp;sning:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1275"/>
        <source>&amp;Hide off screen</source>
        <translation>&amp;Skjul udenfor skærmen</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1306"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../theme.cpp" line="149"/>
        <source>Choose an Openbox theme</source>
        <translation>Vælg et Openbox-tema</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="65"/>
        <location filename="../desktops.cpp" line="87"/>
        <location filename="../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(unavngivet skrivebord)</translation>
    </message>
    <message>
        <location filename="../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Tilpassede handlinger</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Om ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>En præferencehåndtering til Openbox

Ophavsret (c) 2014-2015

Forfattere:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Programmet er baseret på ObConf udviklet af følgende udviklere.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>&quot;%1&quot; blev installeret på %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; blev oprettet med succes</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Kan ikke oprette tema-arkivet &quot;%1&quot;.
Følgende fejl blev rapporteret:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Kan ikke køre &quot;tar&quot;-kommandoen: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Kan ikke oprette mappen &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>&quot;%1&quot; ser ikke ud til at være en gyldig mappe til Openbox-temaer</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Kan ikke flytte til mappen &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Kan ikke udpakke filen &quot;%1&quot;.
Sørg venligst for at &quot;%2&quot; er skrivbar og at filen er et gyldigt arkiv med Openbox-tema.
Følgende fejl blev rapporteret:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>ObConf-fejl</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Ophavsret (c) 2003-2008   Dana Jansens
Ophavsret (c) 2003        Tim Riley
Ophavsret (c) 2007        Javeed Shaikh
Ophavsret (c) 2013        Hong Jen Yee (PCMan)

Dette program kommer med ABSOLUT INGEN GARANTI.
Dette er fri software, og du er velkommen til at videredistribuere det
under bestemte betingelser. Se filen COPYING for detaljer.

</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Syntaks: obconf [tilvalg] [ARKIV.obt]

Tilvalg:
  --help                Vis denne hjælpetekst og afslut
  --version             Vis versionsnummeret og afslut
  --install ARCHIVE.obt Installer det angivne tema-arkiv og vælg det
  --archive THEME       Opret et tema-arkiv fra den angivne tema-mappe
  --config-file FILE    Specificer stien til konfigurationsfilen der skal bruges
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install kræver et argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive kræver et argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file kræver et argument
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="223"/>
        <location filename="../obconf-qt.cpp" line="238"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="224"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Kunne ikke indlæse en rc.xml. Du har muligvis ikke fået installeret Openbox ordentligt.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="236"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Fejl ved fortolkning af Openbox&apos; konfigurationsfil. Din konfigurationsfil er ikke gyldig XML.

Meddelelse: %1</translation>
    </message>
</context>
</TS>
